@@ -361,7 +361,7 @@ func TestJobFailure(t *testing.T) {
 	thrownErr := &BuildError{Inner: errors.New("test error")}
 	executor.On("Shell").Return(&ShellScriptInfo{Shell: "script-shell"})
 	executor.On("Run", matchBuildStage(BuildStagePrepare)).Return(nil).Once()
-	executor.On("Run", mock.Anything).Return(thrownErr).Times(2)
+	executor.On("Run", mock.Anything).Return(thrownErr).Times(3)
 	executor.On("Run", matchBuildStage(BuildStageCleanupFileVariables)).Return(nil).Once()
 	executor.On("Finish", thrownErr).Once()
 
@@ -383,6 +383,7 @@ func TestJobFailure(t *testing.T) {
 	trace.On("Write", mock.Anything).Return(0, nil)
 	trace.On("IsStdout").Return(true)
 	trace.On("SetCancelFunc", mock.Anything).Once()
+	trace.On("SetAbortFunc", mock.Anything).Once()
 	trace.On("SetMasked", mock.Anything).Once()
 	trace.On("Fail", thrownErr, ScriptFailure).Once()
 
@@ -417,6 +418,7 @@ func TestJobFailureOnExecutionTimeout(t *testing.T) {
 	trace.On("Write", mock.Anything).Return(0, nil)
 	trace.On("IsStdout").Return(true)
 	trace.On("SetCancelFunc", mock.Anything).Once()
+	trace.On("SetAbortFunc", mock.Anything).Once()
 	trace.On("SetMasked", mock.Anything).Once()
 	trace.On("Fail", mock.Anything, JobExecutionTimeout).Run(func(arguments mock.Arguments) {
 		assert.Error(t, arguments.Get(0).(error))
@@ -445,6 +447,7 @@ func TestRunFailureRunsAfterScriptAndArtifactsOnFailure(t *testing.T) {
 	executor.On("Run", matchBuildStage("step_script")).Return(errors.New("build fail")).Once()
 	executor.On("Run", matchBuildStage(BuildStageAfterScript)).Return(nil).Once()
 	executor.On("Run", matchBuildStage(BuildStageUploadOnFailureArtifacts)).Return(nil).Once()
+	executor.On("Run", matchBuildStage(BuildStageArchiveOnFailureCache)).Return(nil).Once()
 	executor.On("Run", matchBuildStage(BuildStageCleanupFileVariables)).Return(nil).Once()
 	executor.On("Finish", errors.New("build fail")).Once()
 
@@ -476,6 +479,7 @@ func TestGetSourcesRunFailure(t *testing.T) {
 	executor.On("Shell").Return(&ShellScriptInfo{Shell: "script-shell"})
 	executor.On("Run", matchBuildStage(BuildStagePrepare)).Return(nil).Once()
 	executor.On("Run", matchBuildStage(BuildStageGetSources)).Return(errors.New("build fail")).Times(3)
+	executor.On("Run", matchBuildStage(BuildStageArchiveOnFailureCache)).Return(nil).Once()
 	executor.On("Run", matchBuildStage(BuildStageUploadOnFailureArtifacts)).Return(nil).Once()
 	executor.On("Run", matchBuildStage(BuildStageCleanupFileVariables)).Return(nil).Once()
 	executor.On("Finish", errors.New("build fail")).Once()
@@ -500,6 +504,7 @@ func TestArtifactDownloadRunFailure(t *testing.T) {
 	executor.On("Run", matchBuildStage(BuildStageGetSources)).Return(nil).Once()
 	executor.On("Run", matchBuildStage(BuildStageRestoreCache)).Return(nil).Once()
 	executor.On("Run", matchBuildStage(BuildStageDownloadArtifacts)).Return(errors.New("build fail")).Times(3)
+	executor.On("Run", matchBuildStage(BuildStageArchiveOnFailureCache)).Return(nil).Once()
 	executor.On("Run", matchBuildStage(BuildStageUploadOnFailureArtifacts)).Return(nil).Once()
 	executor.On("Run", matchBuildStage(BuildStageCleanupFileVariables)).Return(nil).Once()
 	executor.On("Finish", errors.New("build fail")).Once()
@@ -526,7 +531,7 @@ func TestArtifactUploadRunFailure(t *testing.T) {
 	executor.On("Run", matchBuildStage(BuildStageDownloadArtifacts)).Return(nil).Once()
 	executor.On("Run", matchBuildStage("step_script")).Return(nil).Once()
 	executor.On("Run", matchBuildStage(BuildStageAfterScript)).Return(nil).Once()
-	executor.On("Run", matchBuildStage(BuildStageArchiveCache)).Return(nil).Once()
+	executor.On("Run", matchBuildStage(BuildStageArchiveOnSuccessCache)).Return(nil).Once()
 	executor.On("Run", matchBuildStage(BuildStageUploadOnSuccessArtifacts)).Return(errors.New("upload fail")).Once()
 	executor.On("Run", matchBuildStage(BuildStageCleanupFileVariables)).Return(nil).Once()
 	executor.On("Finish", errors.New("upload fail")).Once()
@@ -544,6 +549,58 @@ func TestArtifactUploadRunFailure(t *testing.T) {
 	assert.EqualError(t, err, "upload fail")
 }
 
+func TestArchiveCacheOnScriptFailure(t *testing.T) {
+	executor, provider := setupMockExecutorAndProvider()
+	defer executor.AssertExpectations(t)
+	defer provider.AssertExpectations(t)
+	executor.On("Prepare", mock.Anything, mock.Anything, mock.Anything).
+		Return(nil).Once()
+	executor.On("Cleanup").Once()
+
+	// Fail a build script
+	executor.On("Shell").Return(&ShellScriptInfo{Shell: "script-shell"}).Times(9)
+	executor.On("Run", matchBuildStage(BuildStagePrepare)).Return(nil).Once()
+	executor.On("Run", matchBuildStage(BuildStageGetSources)).Return(nil).Once()
+	executor.On("Run", matchBuildStage(BuildStageRestoreCache)).Return(nil).Once()
+	executor.On("Run", matchBuildStage(BuildStageDownloadArtifacts)).Return(nil).Once()
+	executor.On("Run", matchBuildStage("step_script")).Return(errors.New("script failure")).Once()
+	executor.On("Run", matchBuildStage(BuildStageAfterScript)).Return(nil).Once()
+	executor.On("Run", matchBuildStage(BuildStageArchiveOnFailureCache)).Return(nil).Once()
+	executor.On("Run", matchBuildStage(BuildStageUploadOnFailureArtifacts)).Return(nil).Once()
+	executor.On("Run", matchBuildStage(BuildStageCleanupFileVariables)).Return(nil).Once()
+	executor.On("Finish", errors.New("script failure")).Once()
+
+	build := registerExecutorWithSuccessfulBuild(t, provider, new(RunnerConfig))
+	err := build.Run(&Config{}, &Trace{Writer: os.Stdout})
+	assert.EqualError(t, err, "script failure")
+}
+
+func TestUploadArtifactsOnArchiveCacheFailure(t *testing.T) {
+	executor, provider := setupMockExecutorAndProvider()
+	defer executor.AssertExpectations(t)
+	defer provider.AssertExpectations(t)
+	executor.On("Prepare", mock.Anything, mock.Anything, mock.Anything).
+		Return(nil).Once()
+	executor.On("Cleanup").Once()
+
+	// Successful build script
+	executor.On("Shell").Return(&ShellScriptInfo{Shell: "script-shell"}).Times(9)
+	executor.On("Run", matchBuildStage(BuildStagePrepare)).Return(nil).Once()
+	executor.On("Run", matchBuildStage(BuildStageGetSources)).Return(nil).Once()
+	executor.On("Run", matchBuildStage(BuildStageRestoreCache)).Return(nil).Once()
+	executor.On("Run", matchBuildStage(BuildStageDownloadArtifacts)).Return(nil).Once()
+	executor.On("Run", matchBuildStage("step_script")).Return(nil).Once()
+	executor.On("Run", matchBuildStage(BuildStageAfterScript)).Return(nil).Once()
+	executor.On("Run", matchBuildStage(BuildStageArchiveOnSuccessCache)).Return(errors.New("cache failure")).Once()
+	executor.On("Run", matchBuildStage(BuildStageUploadOnSuccessArtifacts)).Return(nil).Once()
+	executor.On("Run", matchBuildStage(BuildStageCleanupFileVariables)).Return(nil).Once()
+	executor.On("Finish", errors.New("cache failure")).Once()
+
+	build := registerExecutorWithSuccessfulBuild(t, provider, new(RunnerConfig))
+	err := build.Run(&Config{}, &Trace{Writer: os.Stdout})
+	assert.EqualError(t, err, "cache failure")
+}
+
 func TestRestoreCacheRunFailure(t *testing.T) {
 	executor, provider := setupMockExecutorAndProvider()
 	defer executor.AssertExpectations(t)
@@ -557,6 +614,7 @@ func TestRestoreCacheRunFailure(t *testing.T) {
 	executor.On("Run", matchBuildStage(BuildStagePrepare)).Return(nil).Once()
 	executor.On("Run", matchBuildStage(BuildStageGetSources)).Return(nil).Once()
 	executor.On("Run", matchBuildStage(BuildStageRestoreCache)).Return(errors.New("build fail")).Times(3)
+	executor.On("Run", matchBuildStage(BuildStageArchiveOnFailureCache)).Return(nil).Once()
 	executor.On("Run", matchBuildStage(BuildStageUploadOnFailureArtifacts)).Return(nil).Once()
 	executor.On("Run", matchBuildStage(BuildStageCleanupFileVariables)).Return(nil).Once()
 	executor.On("Finish", errors.New("build fail")).Once()
@@ -680,15 +738,48 @@ func TestDebugTrace(t *testing.T) {
 }
 
 func TestDefaultEnvVariables(t *testing.T) {
-	buildDir := "/tmp/test-build/dir"
-	build := Build{
-		BuildDir: buildDir,
+	tests := map[string]struct {
+		buildDir      string
+		expectedValue string
+	}{
+		"UNIX-style BuildDir": {
+			buildDir:      "/tmp/test-build/dir",
+			expectedValue: "CI_PROJECT_DIR=/tmp/test-build/dir",
+		},
+		// The next four tests' expected value will depend on the platform running the tests
+		"Windows UNC-style BuildDir (extended-length path support)": {
+			buildDir:      `\\?\C:\tmp\test-build\dir`,
+			expectedValue: "CI_PROJECT_DIR=" + filepath.FromSlash("//?/C:/tmp/test-build/dir"),
+		},
+		"Windows UNC-style BuildDir": {
+			buildDir:      `\\host\share\tmp\test-build\dir`,
+			expectedValue: "CI_PROJECT_DIR=" + filepath.FromSlash("//host/share/tmp/test-build/dir"),
+		},
+		"Windows-style BuildDir (CMD or PS)": {
+			buildDir:      `C:\tmp\test-build\dir`,
+			expectedValue: "CI_PROJECT_DIR=" + filepath.FromSlash("C:/tmp/test-build/dir"),
+		},
+		"Windows-style BuildDir with forward slashes and drive letter": {
+			buildDir:      "C:/tmp/test-build/dir",
+			expectedValue: "CI_PROJECT_DIR=" + filepath.FromSlash("C:/tmp/test-build/dir"),
+		},
+		"Windows-style BuildDir in MSYS bash executor and drive letter)": {
+			buildDir:      "/c/tmp/test-build/dir",
+			expectedValue: "CI_PROJECT_DIR=/c/tmp/test-build/dir",
+		},
 	}
 
-	vars := build.GetAllVariables().StringList()
+	for name, test := range tests {
+		t.Run(name, func(t *testing.T) {
+			build := new(Build)
+			build.BuildDir = test.buildDir
 
-	assert.Contains(t, vars, "CI_PROJECT_DIR="+filepath.FromSlash(buildDir))
-	assert.Contains(t, vars, "CI_SERVER=yes")
+			vars := build.GetAllVariables().StringList()
+
+			assert.Contains(t, vars, test.expectedValue)
+			assert.Contains(t, vars, "CI_SERVER=yes")
+		})
+	}
 }
 
 func TestSharedEnvVariables(t *testing.T) {
@@ -1543,7 +1634,7 @@ func setupSuccessfulMockExecutor(
 	executor.On("Run", matchBuildStage(BuildStageDownloadArtifacts)).Return(nil).Once()
 	executor.On("Run", matchBuildStage("step_script")).Return(nil).Once()
 	executor.On("Run", matchBuildStage(BuildStageAfterScript)).Return(nil).Once()
-	executor.On("Run", matchBuildStage(BuildStageArchiveCache)).Return(nil).Once()
+	executor.On("Run", matchBuildStage(BuildStageArchiveOnSuccessCache)).Return(nil).Once()
 	executor.On("Run", matchBuildStage(BuildStageUploadOnSuccessArtifacts)).
 		Return(nil).
 		Once()
