@@ -278,8 +278,8 @@ func TestDockerCommandUsingCustomClonePath(t *testing.T) {
 }
 
 func TestDockerCommandNoRootImage(t *testing.T) {
-	helpers.SkipIntegrationTests(t, "docker", "info")
 	test.SkipIfGitLabCIOn(t, test.OSWindows)
+	helpers.SkipIntegrationTests(t, "docker", "info")
 
 	successfulBuild, err := common.GetRemoteSuccessfulBuildWithDumpedVariables()
 
@@ -302,8 +302,8 @@ func TestDockerCommandNoRootImage(t *testing.T) {
 }
 
 func TestDockerCommandWithAllowedImagesRun(t *testing.T) {
-	helpers.SkipIntegrationTests(t, "docker", "info")
 	test.SkipIfGitLabCIOn(t, test.OSWindows)
+	helpers.SkipIntegrationTests(t, "docker", "info")
 
 	successfulBuild, err := common.GetRemoteSuccessfulBuild()
 	successfulBuild.Image = common.Image{Name: "$IMAGE_NAME"}
@@ -336,8 +336,8 @@ func TestDockerCommandWithAllowedImagesRun(t *testing.T) {
 }
 
 func TestDockerCommandDisableEntrypointOverwrite(t *testing.T) {
-	helpers.SkipIntegrationTests(t, "docker", "info")
 	test.SkipIfGitLabCIOn(t, test.OSWindows)
+	helpers.SkipIntegrationTests(t, "docker", "info")
 
 	tests := []struct {
 		name     string
@@ -428,9 +428,7 @@ func isDockerOlderThan17_07(t *testing.T) bool {
 }
 
 func TestDockerCommandMissingImage(t *testing.T) {
-	if helpers.SkipIntegrationTests(t, "docker", "info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "docker", "info")
 
 	build := getBuildForOS(t, common.GetSuccessfulBuild)
 	build.Runner.Docker.Image = "some/non-existing/image"
@@ -448,9 +446,7 @@ func TestDockerCommandMissingImage(t *testing.T) {
 }
 
 func TestDockerCommandMissingTag(t *testing.T) {
-	if helpers.SkipIntegrationTests(t, "docker", "info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "docker", "info")
 
 	build := getBuildForOS(t, common.GetSuccessfulBuild)
 	build.Runner.Docker.Image = "docker:missing-tag"
@@ -462,16 +458,14 @@ func TestDockerCommandMissingTag(t *testing.T) {
 }
 
 func TestDockerCommandBuildCancel(t *testing.T) {
-	if helpers.SkipIntegrationTests(t, "docker", "info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "docker", "info")
 
 	buildtest.RunBuildWithCancel(t, getRunnerConfigForOS(t), nil)
 }
 
 func TestDockerCommandTwoServicesFromOneImage(t *testing.T) {
-	helpers.SkipIntegrationTests(t, "docker", "info")
 	test.SkipIfGitLabCIOn(t, test.OSWindows)
+	helpers.SkipIntegrationTests(t, "docker", "info")
 
 	tests := map[string]struct {
 		variables common.JobVariables
@@ -525,8 +519,8 @@ func TestDockerCommandTwoServicesFromOneImage(t *testing.T) {
 }
 
 func TestDockerCommandOutput(t *testing.T) {
-	helpers.SkipIntegrationTests(t, "docker", "info")
 	test.SkipIfGitLabCIOn(t, test.OSWindows)
+	helpers.SkipIntegrationTests(t, "docker", "info")
 
 	successfulBuild, err := common.GetRemoteSuccessfulBuild()
 	assert.NoError(t, err)
@@ -556,9 +550,7 @@ func TestDockerCommandOutput(t *testing.T) {
 
 func TestDockerPrivilegedServiceAccessingBuildsFolder(t *testing.T) {
 	test.SkipIfGitLabCIOn(t, test.OSWindows)
-	if helpers.SkipIntegrationTests(t, "docker", "info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "docker", "info")
 
 	commands := []string{
 		"docker info",
@@ -646,9 +638,7 @@ func getTestDockerJob(t *testing.T) *common.Build {
 
 func TestDockerExtendedConfigurationFromJob(t *testing.T) {
 	test.SkipIfGitLabCIOn(t, test.OSWindows)
-	if helpers.SkipIntegrationTests(t, "docker", "info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "docker", "info")
 
 	examples := []struct {
 		image     common.Image
@@ -716,9 +706,7 @@ func runTestJobWithOutput(t *testing.T, build *common.Build) (output string) {
 
 func TestCacheInContainer(t *testing.T) {
 	test.SkipIfGitLabCIOn(t, test.OSWindows)
-	if helpers.SkipIntegrationTests(t, "docker", "info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "docker", "info")
 
 	successfulBuild, err := common.GetRemoteSuccessfulBuild()
 	assert.NoError(t, err)
@@ -735,6 +723,7 @@ func TestCacheInContainer(t *testing.T) {
 			Key:    "key",
 			Paths:  common.ArtifactPaths{"cached/*"},
 			Policy: common.CachePolicyPullPush,
+			When:   common.CacheWhenOnSuccess,
 		},
 	}
 
@@ -803,9 +792,7 @@ func TestCacheInContainer(t *testing.T) {
 
 func TestDockerImageNameFromVariable(t *testing.T) {
 	test.SkipIfGitLabCIOn(t, test.OSWindows)
-	if helpers.SkipIntegrationTests(t, "docker", "info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "docker", "info")
 
 	successfulBuild, err := common.GetRemoteSuccessfulBuild()
 	successfulBuild.Variables = append(successfulBuild.Variables, common.JobVariable{
@@ -838,9 +825,7 @@ func TestDockerImageNameFromVariable(t *testing.T) {
 
 func TestDockerServiceNameFromVariable(t *testing.T) {
 	test.SkipIfGitLabCIOn(t, test.OSWindows)
-	if helpers.SkipIntegrationTests(t, "docker", "info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "docker", "info")
 
 	successfulBuild, err := common.GetRemoteSuccessfulBuild()
 	successfulBuild.Variables = append(successfulBuild.Variables, common.JobVariable{
@@ -1083,50 +1068,50 @@ func testDockerVersion(t *testing.T, version string) {
 }
 
 func TestDocker1_8Compatibility(t *testing.T) {
-	helpers.SkipIntegrationTests(t, "docker", "info")
 	test.SkipIfGitLabCIWithMessage(t, "This test doesn't work in nested dind")
+	helpers.SkipIntegrationTests(t, "docker", "info")
 
 	testDockerVersion(t, "1.8")
 }
 
 func TestDocker1_9Compatibility(t *testing.T) {
-	helpers.SkipIntegrationTests(t, "docker", "info")
 	test.SkipIfGitLabCIWithMessage(t, "This test doesn't work in nested dind")
+	helpers.SkipIntegrationTests(t, "docker", "info")
 
 	testDockerVersion(t, "1.9")
 }
 
 func TestDocker1_10Compatibility(t *testing.T) {
-	helpers.SkipIntegrationTests(t, "docker", "info")
 	test.SkipIfGitLabCIWithMessage(t, "This test doesn't work in nested dind")
+	helpers.SkipIntegrationTests(t, "docker", "info")
 
 	testDockerVersion(t, "1.10")
 }
 
 func TestDocker1_11Compatibility(t *testing.T) {
-	helpers.SkipIntegrationTests(t, "docker", "info")
 	test.SkipIfGitLabCIWithMessage(t, "This test doesn't work in nested dind")
+	helpers.SkipIntegrationTests(t, "docker", "info")
 
 	testDockerVersion(t, "1.11")
 }
 
 func TestDocker1_12Compatibility(t *testing.T) {
-	helpers.SkipIntegrationTests(t, "docker", "info")
 	test.SkipIfGitLabCIWithMessage(t, "This test doesn't work in nested dind")
+	helpers.SkipIntegrationTests(t, "docker", "info")
 
 	testDockerVersion(t, "1.12")
 }
 
 func TestDocker1_13Compatibility(t *testing.T) {
-	helpers.SkipIntegrationTests(t, "docker", "info")
 	test.SkipIfGitLabCIWithMessage(t, "This test doesn't work in nested dind")
+	helpers.SkipIntegrationTests(t, "docker", "info")
 
 	testDockerVersion(t, "1.13")
 }
 
 func TestDockerCommandWithBrokenGitSSLCAInfo(t *testing.T) {
-	helpers.SkipIntegrationTests(t, "docker", "info")
 	test.SkipIfGitLabCIOn(t, test.OSWindows)
+	helpers.SkipIntegrationTests(t, "docker", "info")
 
 	successfulBuild, err := common.GetRemoteBrokenTLSBuild()
 	assert.NoError(t, err)
@@ -1156,8 +1141,8 @@ func TestDockerCommandWithBrokenGitSSLCAInfo(t *testing.T) {
 }
 
 func TestDockerCommandWithGitSSLCAInfo(t *testing.T) {
-	helpers.SkipIntegrationTests(t, "docker", "info")
 	test.SkipIfGitLabCIOn(t, test.OSWindows)
+	helpers.SkipIntegrationTests(t, "docker", "info")
 
 	successfulBuild, err := common.GetRemoteGitLabComTLSBuild()
 	assert.NoError(t, err)
@@ -1187,8 +1172,8 @@ func TestDockerCommandWithGitSSLCAInfo(t *testing.T) {
 }
 
 func TestDockerCommandWithHelperImageConfig(t *testing.T) {
-	helpers.SkipIntegrationTests(t, "docker", "info")
 	test.SkipIfGitLabCIOn(t, test.OSWindows)
+	helpers.SkipIntegrationTests(t, "docker", "info")
 
 	helperImageConfig := "gitlab/gitlab-runner-helper:x86_64-5a147c92"
 
@@ -1222,8 +1207,8 @@ func TestDockerCommandWithHelperImageConfig(t *testing.T) {
 }
 
 func TestDockerCommandWithDoingPruneAndAfterScript(t *testing.T) {
-	helpers.SkipIntegrationTests(t, "docker", "info")
 	test.SkipIfGitLabCIOn(t, test.OSWindows)
+	helpers.SkipIntegrationTests(t, "docker", "info")
 
 	successfulBuild, err := common.GetRemoteSuccessfulBuildWithAfterScript()
 
@@ -1263,9 +1248,7 @@ func TestDockerCommandWithDoingPruneAndAfterScript(t *testing.T) {
 func TestDockerCommandRunAttempts(t *testing.T) {
 	t.Skip("Skipping until https://gitlab.com/gitlab-org/gitlab-runner/-/issues/25385 is resolved.")
 
-	if helpers.SkipIntegrationTests(t, "docker", "info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "docker", "info")
 
 	sleepCMD := "sleep 60"
 	executorStageAttempts := 2
@@ -1377,9 +1360,7 @@ func removeBuildContainer(t *testing.T) <-chan string {
 }
 
 func TestDockerCommandRunAttempts_InvalidAttempts(t *testing.T) {
-	if helpers.SkipIntegrationTests(t, "docker", "info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "docker", "info")
 
 	build := getBuildForOS(t, common.GetRemoteSuccessfulBuild)
 	build.JobResponse.Variables = append(build.JobResponse.Variables, common.JobVariable{
