@@ -310,13 +310,14 @@ func TestHelperImageWithVariable(t *testing.T) {
 	c := new(docker.MockClient)
 	defer c.AssertExpectations(t)
 
-	c.On("ImageInspectWithRaw", mock.Anything, "gitlab/gitlab-runner:HEAD").
+	runnerImageTag := "gitlab/gitlab-runner:" + common.REVISION
+	c.On("ImageInspectWithRaw", mock.Anything, runnerImageTag).
 		Return(types.ImageInspect{}, nil, errors.New("not found")).
 		Once()
-	c.On("ImagePullBlocking", mock.Anything, "gitlab/gitlab-runner:HEAD", mock.Anything).
+	c.On("ImagePullBlocking", mock.Anything, runnerImageTag, mock.Anything).
 		Return(nil).
 		Once()
-	c.On("ImageInspectWithRaw", mock.Anything, "gitlab/gitlab-runner:HEAD").
+	c.On("ImageInspectWithRaw", mock.Anything, runnerImageTag).
 		Return(types.ImageInspect{ID: "helper-image"}, nil, nil).
 		Once()
 
@@ -1186,9 +1187,7 @@ func TestPullPolicyWhenIfNotPresentIsSet(t *testing.T) {
 
 func TestDockerWatchOn_1_12_4(t *testing.T) {
 	test.SkipIfGitLabCIOn(t, test.OSWindows)
-	if helpers.SkipIntegrationTests(t, "docker", "info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "docker", "info")
 
 	e := &executor{
 		AbstractExecutor: executors.AbstractExecutor{
