@@ -11,6 +11,8 @@ import (
 	"github.com/stretchr/testify/mock"
 	"github.com/stretchr/testify/require"
 
+	"gitlab.com/gitlab-org/gitlab-runner/common"
+	"gitlab.com/gitlab-org/gitlab-runner/executors/docker/internal/labels"
 	"gitlab.com/gitlab-org/gitlab-runner/executors/docker/internal/volumes/parser"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers/docker"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers/docker/test"
@@ -32,15 +34,20 @@ func TestErrVolumeAlreadyDefined(t *testing.T) {
 func TestNewDefaultManager(t *testing.T) {
 	logger := newDebugLoggerMock()
 
-	m := NewManager(logger, nil, nil, ManagerConfig{})
+	m := NewManager(logger, nil, nil, ManagerConfig{}, nil)
 	assert.IsType(t, &manager{}, m)
 }
 
 func newDefaultManager(config ManagerConfig) *manager {
+	b := &common.Build{
+		Runner: &common.RunnerConfig{},
+	}
+
 	m := &manager{
 		logger:         newDebugLoggerMock(),
 		config:         config,
 		managedVolumes: make(map[string]bool),
+		labeler:        labels.NewLabeler(b),
 	}
 
 	return m
@@ -399,7 +406,7 @@ func TestDefaultManager_CreateUserVolumes_CacheVolume_VolumeBased(t *testing.T)
 					"VolumeCreate",
 					mock.Anything,
 					mock.MatchedBy(func(v volume.VolumeCreateBody) bool {
-						return v.Name == testCase.expectedVolumeName
+						return testVolumeCreateBodyContent(v, testCase.expectedVolumeName)
 					}),
 				).
 					Return(types.Volume{Name: testCase.expectedVolumeName}, nil).
@@ -448,7 +455,7 @@ func TestDefaultManager_CreateUserVolumes_CacheVolume_VolumeBased_WithError(t *t
 		"VolumeCreate",
 		mock.Anything,
 		mock.MatchedBy(func(v volume.VolumeCreateBody) bool {
-			return v.Name == "unique-cache-f69aef9fb01e88e6213362a04877452d"
+			return testVolumeCreateBodyContent(v, "unique-cache-f69aef9fb01e88e6213362a04877452d")
 		}),
 	).
 		Return(types.Volume{}, testErr).
@@ -541,7 +548,7 @@ func TestDefaultManager_CreateTemporary(t *testing.T) {
 					"VolumeCreate",
 					mock.Anything,
 					mock.MatchedBy(func(v volume.VolumeCreateBody) bool {
-						return v.Name == testCase.expectedVolumeName
+						return testVolumeCreateBodyContent(v, testCase.expectedVolumeName)
 					}),
 				).
 					Return(types.Volume{Name: testCase.expectedVolumeName}, testCase.volumeCreateErr).
@@ -645,3 +652,10 @@ func TestDefaultManager_Binds(t *testing.T) {
 
 	assert.Equal(t, expectedElements, m.Binds())
 }
+
+func testVolumeCreateBodyContent(v volume.VolumeCreateBody, expectedVolumeName string) bool {
+	return v.Name == expectedVolumeName &&
+		// ensure labeler has been used
+		// test for the full list of labels is part of the labels package.
+		len(v.Labels) > 0 && v.Labels["com.gitlab.gitlab-runner.type"] == "cache"
+}
