@@ -12,7 +12,15 @@ var createVolumesManager = func(e *executor) (volumes.Manager, error) {
 		DisableCache: e.Config.Docker.DisableCache,
 	}
 
-	volumesManager := volumes.NewManager(&e.BuildLogger, e.volumeParser, e.client, config)
+	if e.newVolumePermissionSetter != nil {
+		setter, err := e.newVolumePermissionSetter()
+		if err != nil {
+			return nil, err
+		}
+		config.PermissionSetter = setter
+	}
+
+	volumesManager := volumes.NewManager(&e.BuildLogger, e.volumeParser, e.client, config, e.labeler)
 
 	return volumesManager, nil
 }
