@@ -43,8 +43,8 @@ import (
 
 type featureFlagTest func(t *testing.T, flagName string, flagValue bool)
 
-func mustCreateResourceList(t *testing.T, cpu, memory string) api.ResourceList {
-	resources, err := createResourceList(cpu, memory)
+func mustCreateResourceList(t *testing.T, cpu, memory, ephemeralStorage string) api.ResourceList {
+	resources, err := createResourceList(cpu, memory, ephemeralStorage)
 	require.NoError(t, err)
 
 	return resources
@@ -87,9 +87,7 @@ func TestRunTestsWithFeatureFlag(t *testing.T) {
 }
 
 func testKubernetesSuccessRunFeatureFlag(t *testing.T, featureFlagName string, featureFlagValue bool) {
-	if helpers.SkipIntegrationTests(t, "kubectl", "cluster-info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "kubectl", "cluster-info")
 
 	successfulBuild, err := common.GetRemoteSuccessfulBuild()
 	assert.NoError(t, err)
@@ -202,9 +200,7 @@ func testKubernetesMultistepRunFeatureFlag(t *testing.T, featureFlagName string,
 }
 
 func testKubernetesTimeoutRunFeatureFlag(t *testing.T, featureFlagName string, featureFlagValue bool) {
-	if helpers.SkipIntegrationTests(t, "kubectl", "cluster-info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "kubectl", "cluster-info")
 
 	longRunningBuild, err := common.GetRemoteLongRunningBuild()
 	assert.NoError(t, err)
@@ -231,9 +227,7 @@ func testKubernetesTimeoutRunFeatureFlag(t *testing.T, featureFlagName string, f
 }
 
 func testKubernetesBuildFailFeatureFlag(t *testing.T, featureFlagName string, featureFlagValue bool) {
-	if helpers.SkipIntegrationTests(t, "kubectl", "cluster-info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "kubectl", "cluster-info")
 
 	failedBuild, err := common.GetRemoteFailedBuild()
 	assert.NoError(t, err)
@@ -258,9 +252,7 @@ func testKubernetesBuildFailFeatureFlag(t *testing.T, featureFlagName string, fe
 }
 
 func testKubernetesBuildCancelFeatureFlag(t *testing.T, featureFlagName string, featureFlagValue bool) {
-	if helpers.SkipIntegrationTests(t, "kubectl", "cluster-info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "kubectl", "cluster-info")
 
 	buildtest.RunBuildWithCancel(
 		t,
@@ -589,9 +581,7 @@ func testSetupBuildPodServiceCreationErrorFeatureFlag(t *testing.T, featureFlagN
 }
 
 func testKubernetesCustomClonePathFeatureFlag(t *testing.T, featureFlagName string, featureFlagValue bool) {
-	if helpers.SkipIntegrationTests(t, "kubectl", "cluster-info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "kubectl", "cluster-info")
 
 	jobResponse, err := common.GetRemoteBuildResponse(
 		"ls -al $CI_BUILDS_DIR/go/src/gitlab.com/gitlab-org/repo",
@@ -644,9 +634,7 @@ func testKubernetesCustomClonePathFeatureFlag(t *testing.T, featureFlagName stri
 }
 
 func testKubernetesNoRootImageFeatureFlag(t *testing.T, featureFlagName string, featureFlagValue bool) {
-	if helpers.SkipIntegrationTests(t, "kubectl", "cluster-info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "kubectl", "cluster-info")
 
 	successfulBuild, err := common.GetRemoteSuccessfulBuildWithDumpedVariables()
 
@@ -671,9 +659,7 @@ func testKubernetesNoRootImageFeatureFlag(t *testing.T, featureFlagName string,
 }
 
 func testKubernetesMissingImageFeatureFlag(t *testing.T, featureFlagName string, featureFlagValue bool) {
-	if helpers.SkipIntegrationTests(t, "kubectl", "cluster-info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "kubectl", "cluster-info")
 
 	failedBuild, err := common.GetRemoteFailedBuild()
 	assert.NoError(t, err)
@@ -697,9 +683,7 @@ func testKubernetesMissingImageFeatureFlag(t *testing.T, featureFlagName string,
 }
 
 func testKubernetesMissingTagFeatureFlag(t *testing.T, featureFlagName string, featureFlagValue bool) {
-	if helpers.SkipIntegrationTests(t, "kubectl", "cluster-info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "kubectl", "cluster-info")
 
 	failedBuild, err := common.GetRemoteFailedBuild()
 	assert.NoError(t, err)
@@ -723,9 +707,7 @@ func testKubernetesMissingTagFeatureFlag(t *testing.T, featureFlagName string, f
 }
 
 func testOverwriteNamespaceNotMatchFeatureFlag(t *testing.T, featureFlagName string, featureFlagValue bool) {
-	if helpers.SkipIntegrationTests(t, "kubectl", "cluster-info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "kubectl", "cluster-info")
 
 	build := &common.Build{
 		JobResponse: common.JobResponse{
@@ -759,9 +741,7 @@ func testOverwriteNamespaceNotMatchFeatureFlag(t *testing.T, featureFlagName str
 }
 
 func testOverwriteServiceAccountNotMatchFeatureFlag(t *testing.T, featureFlagName string, featureFlagValue bool) {
-	if helpers.SkipIntegrationTests(t, "kubectl", "cluster-info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "kubectl", "cluster-info")
 
 	build := &common.Build{
 		JobResponse: common.JobResponse{
@@ -795,9 +775,7 @@ func testOverwriteServiceAccountNotMatchFeatureFlag(t *testing.T, featureFlagNam
 }
 
 func testInteractiveTerminalFeatureFlag(t *testing.T, featureFlagName string, featureFlagValue bool) {
-	if helpers.SkipIntegrationTests(t, "kubectl", "cluster-info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "kubectl", "cluster-info")
 
 	if os.Getenv("GITLAB_CI") == "true" {
 		t.Skip("Skipping inside of GitLab CI check https://gitlab.com/gitlab-org/gitlab-runner/-/issues/26421")
@@ -1084,15 +1062,18 @@ func TestPrepare(t *testing.T) {
 			RunnerConfig: &common.RunnerConfig{
 				RunnerSettings: common.RunnerSettings{
 					Kubernetes: &common.KubernetesConfig{
-						Host:               "test-server",
-						ServiceCPULimit:    "100m",
-						ServiceMemoryLimit: "200Mi",
-						CPULimit:           "1.5",
-						MemoryLimit:        "4Gi",
-						HelperCPULimit:     "50m",
-						HelperMemoryLimit:  "100Mi",
-						Privileged:         true,
-						PullPolicy:         "if-not-present",
+						Host:                         "test-server",
+						ServiceCPULimit:              "100m",
+						ServiceMemoryLimit:           "200Mi",
+						ServiceEphemeralStorageLimit: "1Gi",
+						CPULimit:                     "1.5",
+						MemoryLimit:                  "4Gi",
+						EphemeralStorageLimit:        "6Gi",
+						HelperCPULimit:               "50m",
+						HelperMemoryLimit:            "100Mi",
+						HelperEphemeralStorageLimit:  "200Mi",
+						Privileged:                   true,
+						PullPolicy:                   "if-not-present",
 					},
 				},
 			},
@@ -1118,9 +1099,9 @@ func TestPrepare(t *testing.T) {
 				},
 				configurationOverwrites: &overwrites{
 					namespace:       "default",
-					buildLimits:     mustCreateResourceList(t, "1.5", "4Gi"),
-					serviceLimits:   mustCreateResourceList(t, "100m", "200Mi"),
-					helperLimits:    mustCreateResourceList(t, "50m", "100Mi"),
+					buildLimits:     mustCreateResourceList(t, "1.5", "4Gi", "6Gi"),
+					serviceLimits:   mustCreateResourceList(t, "100m", "200Mi", "1Gi"),
+					helperLimits:    mustCreateResourceList(t, "50m", "100Mi", "200Mi"),
 					buildRequests:   api.ResourceList{},
 					serviceRequests: api.ResourceList{},
 					helperRequests:  api.ResourceList{},
@@ -1140,16 +1121,22 @@ func TestPrepare(t *testing.T) {
 						BearerTokenOverwriteAllowed:    true,
 						ServiceCPULimit:                "100m",
 						ServiceMemoryLimit:             "200Mi",
+						ServiceEphemeralStorageLimit:   "2Gi",
 						CPULimit:                       "1.5",
 						MemoryLimit:                    "4Gi",
+						EphemeralStorageLimit:          "3Gi",
 						HelperCPULimit:                 "50m",
 						HelperMemoryLimit:              "100Mi",
+						HelperEphemeralStorageLimit:    "300Mi",
 						ServiceCPURequest:              "99m",
 						ServiceMemoryRequest:           "5Mi",
+						ServiceEphemeralStorageRequest: "200Mi",
 						CPURequest:                     "1",
 						MemoryRequest:                  "1.5Gi",
+						EphemeralStorageRequest:        "1.3Gi",
 						HelperCPURequest:               "0.5m",
 						HelperMemoryRequest:            "42Mi",
+						HelperEphemeralStorageRequest:  "99Mi",
 						Privileged:                     false,
 					},
 				},
@@ -1177,12 +1164,12 @@ func TestPrepare(t *testing.T) {
 				configurationOverwrites: &overwrites{
 					namespace:       "default",
 					serviceAccount:  "not-default",
-					buildLimits:     mustCreateResourceList(t, "1.5", "4Gi"),
-					buildRequests:   mustCreateResourceList(t, "1", "1.5Gi"),
-					serviceLimits:   mustCreateResourceList(t, "100m", "200Mi"),
-					serviceRequests: mustCreateResourceList(t, "99m", "5Mi"),
-					helperLimits:    mustCreateResourceList(t, "50m", "100Mi"),
-					helperRequests:  mustCreateResourceList(t, "0.5m", "42Mi"),
+					buildLimits:     mustCreateResourceList(t, "1.5", "4Gi", "3Gi"),
+					buildRequests:   mustCreateResourceList(t, "1", "1.5Gi", "1.3Gi"),
+					serviceLimits:   mustCreateResourceList(t, "100m", "200Mi", "2Gi"),
+					serviceRequests: mustCreateResourceList(t, "99m", "5Mi", "200Mi"),
+					helperLimits:    mustCreateResourceList(t, "50m", "100Mi", "300Mi"),
+					helperRequests:  mustCreateResourceList(t, "0.5m", "42Mi", "99Mi"),
 				},
 			},
 		},
@@ -1198,16 +1185,22 @@ func TestPrepare(t *testing.T) {
 						ServiceAccountOverwriteAllowed: "allowed-.*",
 						ServiceCPULimit:                "100m",
 						ServiceMemoryLimit:             "200Mi",
+						ServiceEphemeralStorageLimit:   "300Mi",
 						CPULimit:                       "1.5",
 						MemoryLimit:                    "4Gi",
+						EphemeralStorageLimit:          "5Gi",
 						HelperCPULimit:                 "50m",
 						HelperMemoryLimit:              "100Mi",
+						HelperEphemeralStorageLimit:    "200Mi",
 						ServiceCPURequest:              "99m",
 						ServiceMemoryRequest:           "5Mi",
+						ServiceEphemeralStorageRequest: "50Mi",
 						CPURequest:                     "1",
 						MemoryRequest:                  "1.5Gi",
+						EphemeralStorageRequest:        "40Mi",
 						HelperCPURequest:               "0.5m",
 						HelperMemoryRequest:            "42Mi",
+						HelperEphemeralStorageRequest:  "52Mi",
 						Privileged:                     false,
 					},
 				},
@@ -1240,16 +1233,22 @@ func TestPrepare(t *testing.T) {
 						NamespaceOverwriteAllowed:      "^n.*?e$",
 						ServiceCPULimit:                "100m",
 						ServiceMemoryLimit:             "200Mi",
+						ServiceEphemeralStorageLimit:   "300Mi",
 						CPULimit:                       "1.5",
 						MemoryLimit:                    "4Gi",
+						EphemeralStorageLimit:          "5Gi",
 						HelperCPULimit:                 "50m",
 						HelperMemoryLimit:              "100Mi",
+						HelperEphemeralStorageLimit:    "300Mi",
 						ServiceCPURequest:              "99m",
 						ServiceMemoryRequest:           "5Mi",
+						ServiceEphemeralStorageRequest: "15Mi",
 						CPURequest:                     "1",
 						MemoryRequest:                  "1.5Gi",
+						EphemeralStorageRequest:        "1.7Gi",
 						HelperCPURequest:               "0.5m",
 						HelperMemoryRequest:            "42Mi",
+						HelperEphemeralStorageRequest:  "32Mi",
 						Privileged:                     false,
 					},
 				},
@@ -1277,12 +1276,12 @@ func TestPrepare(t *testing.T) {
 				configurationOverwrites: &overwrites{
 					namespace:       "new-namespace-name",
 					serviceAccount:  "a_service_account",
-					buildLimits:     mustCreateResourceList(t, "1.5", "4Gi"),
-					buildRequests:   mustCreateResourceList(t, "1", "1.5Gi"),
-					serviceLimits:   mustCreateResourceList(t, "100m", "200Mi"),
-					serviceRequests: mustCreateResourceList(t, "99m", "5Mi"),
-					helperLimits:    mustCreateResourceList(t, "50m", "100Mi"),
-					helperRequests:  mustCreateResourceList(t, "0.5m", "42Mi"),
+					buildLimits:     mustCreateResourceList(t, "1.5", "4Gi", "5Gi"),
+					buildRequests:   mustCreateResourceList(t, "1", "1.5Gi", "1.7Gi"),
+					serviceLimits:   mustCreateResourceList(t, "100m", "200Mi", "300Mi"),
+					serviceRequests: mustCreateResourceList(t, "99m", "5Mi", "15Mi"),
+					helperLimits:    mustCreateResourceList(t, "50m", "100Mi", "300Mi"),
+					helperRequests:  mustCreateResourceList(t, "0.5m", "42Mi", "32Mi"),
 				},
 			},
 		},
@@ -1532,9 +1531,7 @@ func TestPrepare(t *testing.T) {
 
 // This test reproduces the bug reported in https://gitlab.com/gitlab-org/gitlab-runner/issues/2583
 func TestPrepareIssue2583(t *testing.T) {
-	if helpers.SkipIntegrationTests(t, "kubectl", "cluster-info") {
-		return
-	}
+	helpers.SkipIntegrationTests(t, "kubectl", "cluster-info")
 
 	namespace := "my_namespace"
 	serviceAccount := "my_account"
@@ -1917,7 +1914,7 @@ func TestSetupBuildPod(t *testing.T) {
 			VerifyFn: func(t *testing.T, test setupBuildPodTestDef, pod *api.Pod) {
 				for _, c := range pod.Spec.Containers {
 					if c.Name == "helper" {
-						assert.Equal(t, "custom/helper-image:HEAD", c.Image)
+						assert.Equal(t, "custom/helper-image:"+common.REVISION, c.Image)
 					}
 				}
 			},
@@ -3200,6 +3197,8 @@ func (f FakeBuildTrace) Fail(err error, failureReason common.JobFailureReason) {
 func (f FakeBuildTrace) Notify(func())                                         {}
 func (f FakeBuildTrace) SetCancelFunc(cancelFunc context.CancelFunc)           {}
 func (f FakeBuildTrace) Cancel() bool                                          { return false }
+func (f FakeBuildTrace) SetAbortFunc(cancelFunc context.CancelFunc)            {}
+func (f FakeBuildTrace) Abort() bool                                           { return false }
 func (f FakeBuildTrace) SetFailuresCollector(fc common.FailuresCollector)      {}
 func (f FakeBuildTrace) SetMasked(masked []string)                             {}
 func (f FakeBuildTrace) IsStdout() bool {
